Struct AtomicDestroy

pub struct AtomicDestroy<T> { /* private fields */ }
An atomically destroyable value.

Implementations

Source

impl<T> AtomicDestroy<T>

pub const fn new(value: T) -> Self

Create a new atomically destroyable value.

pub const fn empty() -> Self

Create an atomically destroyable value that has already been dropped.

pub fn maybe_new(value: Option<T>) -> Self

Create an atomically destroyable value from an Option<T>.

pub fn get(&self) -> Option<Value<T, &Self>>

Get the value if it hasn’t been destroyed.

pub fn with<R>(&self, f: impl FnOnce(&T) -> R) -> Option<R>

Run a function using the value.

pub fn destroy(&self)

Destroy the value. If someone is currently using the value the destructor will be run when they are done.